<!--
SPDX-FileCopyrightText: 2023 Bundesministerium des Innern und für Heimat, PG ZenDiS "Projektgruppe für Aufbau ZenDiS"
SPDX-License-Identifier: Apache-2.0
-->
# sovereign-workplace-jitsi

Deploy Jitsi with additional configuration for SWP.

## Installing the Chart

To install the chart with the release name `my-release`:

```console
helm repo add sovereign-workplace-jitsi https://gitlab.souvap-univention.de/api/v4/projects/137/packages/helm/stable
helm install my-release sovereign-workplace-jitsi/sovereign-workplace-jitsi
```

## Requirements

| Repository | Name | Version |
|------------|------|---------|
| https://charts.bitnami.com/bitnami | common | 2.4.0 |
| https://jitsi-contrib.github.io/jitsi-helm/ | jitsi(jitsi-meet) | 1.3.6 |

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| affinity | object | `{}` | Affinity for pod assignment Ref: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/#affinity-and-anti-affinity Note: podAffinityPreset, podAntiAffinityPreset, and  nodeAffinityPreset will be ignored when it's set |
| cleanup.deletePodsOnSuccess | bool | `true` | Keep Pods/Job logs after successful run. |
| cleanup.keepPVCOnDelete | bool | `false` | Keep persistence on delete of this release. |
| containerSecurityContext.allowPrivilegeEscalation | bool | `false` | Enable container privileged escalation. |
| containerSecurityContext.enabled | bool | `true` | Enable security context. |
| containerSecurityContext.readOnlyRootFilesystem | bool | `true` | Mounts the container's root filesystem as read-only. |
| extraEnvVars | list | `[]` | Array with extra environment variables to add to containers.  extraEnvVars:   - name: FOO     value: "bar"  |
| fullnameOverride | string | `""` | Provide a name to substitute for the full names of resources. |
| global.domain | string | `"souvap-univention.de"` | The Top-Level-Domain (TLD) name which is used in f.e. in Ingress component. |
| global.hosts.keycloak | string | `"id"` | Subdomain for Keycloak, results in "https://{{ keycloak }}.{{ domain }}". |
| global.imagePullSecrets | list | `[]` | Credentials to fetch images from private registry Ref: https://kubernetes.io/docs/tasks/configure-pod-container/pull-image-private-registry/  imagePullSecrets:   - "docker-registry"  |
| global.registry | string | `"docker.io"` | Container registry address. |
| image.imagePullPolicy | string | `"IfNotPresent"` | Define an ImagePullPolicy.  Ref.: https://kubernetes.io/docs/concepts/containers/images/#image-pull-policy  "IfNotPresent" => The image is pulled only if it is not already present locally. "Always" => Every time the kubelet launches a container, the kubelet queries the container image registry to             resolve the name to an image digest. If the kubelet has a container image with that exact digest cached             locally, the kubelet uses its cached image; otherwise, the kubelet pulls the image with the resolved             digest, and uses that image to launch the container. "Never" => The kubelet does not try fetching the image. If the image is somehow already present locally, the            kubelet attempts to start the container; otherwise, startup fails  |
| image.registry | string | `"ghcr.io"` | Container registry address. This setting has higher precedence than global.registry. |
| image.repository | string | `"nordeck/jitsi-keycloak-adapter"` | Container repository string. |
| image.tag | string | `"v20230425"` | Define image tag. |
| imagePullSecrets | list | `[]` | Credentials to fetch images from private registry Ref: https://kubernetes.io/docs/tasks/configure-pod-container/pull-image-private-registry/  imagePullSecrets:   - "docker-registry"  |
| jitsi.enableAuth | bool | `true` |  |
| jitsi.enableGuests | bool | `true` |  |
| jitsi.extraCommonEnvs.ADAPTER_INTERNAL_URL | string | `"http://jitsi-keycloak-adapter:9000"` |  |
| jitsi.extraCommonEnvs.TOOLBAR_BUTTONS | string | `"camera,closedcaptions,desktop,download,feedback,filmstrip,fullscreen,hangup,help,livestreaming,microphone,mute-everyone,mute-video-everyone,participants-pane,profile,raisehand,security,select-background,settings,shareaudio,shortcuts,stats,tileview,toggle-camera,videoquality"` |  |
| jitsi.jibri.enabled | bool | `true` |  |
| jitsi.jibri.image.pullPolicy | string | `"IfNotPresent"` |  |
| jitsi.jibri.image.tag | string | `"stable-8615"` |  |
| jitsi.jibri.livestreaming | bool | `true` |  |
| jitsi.jibri.recording | bool | `true` |  |
| jitsi.jicofo.extraEnvs.AUTH_TYPE | string | `"xmpp"` |  |
| jitsi.jicofo.image.pullPolicy | string | `"IfNotPresent"` |  |
| jitsi.jicofo.image.tag | string | `"stable-8615"` |  |
| jitsi.jvb.image.pullPolicy | string | `"IfNotPresent"` |  |
| jitsi.jvb.image.tag | string | `"stable-8615"` |  |
| jitsi.jvb.replicaCount | int | `2` |  |
| jitsi.jvb.service.enabled | bool | `true` |  |
| jitsi.jvb.service.externalTrafficPolicy | string | `""` |  |
| jitsi.jvb.service.type | string | `"LoadBalancer"` |  |
| jitsi.prosody.extraEnvs[0].name | string | `"AUTH_TYPE"` |  |
| jitsi.prosody.extraEnvs[0].value | string | `"jwt"` |  |
| jitsi.prosody.image.pullPolicy | string | `"IfNotPresent"` |  |
| jitsi.prosody.image.tag | string | `"stable-8615"` |  |
| jitsi.publicURL | string | `"https://jitsi.my-deployment.de"` |  |
| jitsi.tz | string | `"Europe/Berlin"` |  |
| jitsi.web.extraVolumeMounts[0].mountPath | string | `"/config/custom-config.js"` |  |
| jitsi.web.extraVolumeMounts[0].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[0].subPath | string | `"custom-config.js"` |  |
| jitsi.web.extraVolumeMounts[1].mountPath | string | `"/config/custom-interface_config.js"` |  |
| jitsi.web.extraVolumeMounts[1].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[1].subPath | string | `"custom-interface_config.js"` |  |
| jitsi.web.extraVolumeMounts[2].mountPath | string | `"/usr/share/jitsi-meet/images/watermark.svg"` |  |
| jitsi.web.extraVolumeMounts[2].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[2].subPath | string | `"watermark.svg"` |  |
| jitsi.web.extraVolumeMounts[3].mountPath | string | `"/usr/share/jitsi-meet/body.html"` |  |
| jitsi.web.extraVolumeMounts[3].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[3].subPath | string | `"body.oidc.html"` |  |
| jitsi.web.extraVolumeMounts[4].mountPath | string | `"/defaults/meet.conf"` |  |
| jitsi.web.extraVolumeMounts[4].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[4].subPath | string | `"meet.oidc.conf"` |  |
| jitsi.web.extraVolumeMounts[5].mountPath | string | `"/usr/share/jitsi-meet/static/oidc-adapter.html"` |  |
| jitsi.web.extraVolumeMounts[5].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[5].subPath | string | `"oidc-adapter.html"` |  |
| jitsi.web.extraVolumeMounts[6].mountPath | string | `"/usr/share/jitsi-meet/static/oidc-redirect.html"` |  |
| jitsi.web.extraVolumeMounts[6].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumeMounts[6].subPath | string | `"oidc-redirect.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[0].key | string | `"body.oidc.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[0].path | string | `"body.oidc.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[1].key | string | `"custom-config.js"` |  |
| jitsi.web.extraVolumes[0].configMap.items[1].path | string | `"custom-config.js"` |  |
| jitsi.web.extraVolumes[0].configMap.items[2].key | string | `"custom-interface_config.js"` |  |
| jitsi.web.extraVolumes[0].configMap.items[2].path | string | `"custom-interface_config.js"` |  |
| jitsi.web.extraVolumes[0].configMap.items[3].key | string | `"meet.oidc.conf"` |  |
| jitsi.web.extraVolumes[0].configMap.items[3].path | string | `"meet.oidc.conf"` |  |
| jitsi.web.extraVolumes[0].configMap.items[4].key | string | `"oidc-adapter.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[4].path | string | `"oidc-adapter.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[5].key | string | `"oidc-redirect.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[5].path | string | `"oidc-redirect.html"` |  |
| jitsi.web.extraVolumes[0].configMap.items[6].key | string | `"watermark.svg"` |  |
| jitsi.web.extraVolumes[0].configMap.items[6].path | string | `"watermark.svg"` |  |
| jitsi.web.extraVolumes[0].configMap.name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.extraVolumes[0].name | string | `"jitsi-meet-swp"` |  |
| jitsi.web.image.pullPolicy | string | `"IfNotPresent"` |  |
| jitsi.web.image.tag | string | `"stable-8615"` |  |
| jitsi.web.replicaCount | int | `1` |  |
| jitsi.websockets.colibri.enabled | bool | `false` |  |
| jitsi.websockets.xmpp.enabled | bool | `false` |  |
| lifecycleHooks | object | `{}` | Lifecycle to automate configuration before or after startup |
| nameOverride | string | `""` | String to partially override release name. |
| nodeSelector | object | `{}` | Node labels for pod assignment Ref: https://kubernetes.io/docs/user-guide/node-selection/ |
| patchJVB.containerSecurityContext.allowPrivilegeEscalation | bool | `false` | Enable container privileged escalation. |
| patchJVB.containerSecurityContext.enabled | bool | `true` | Enable security context. |
| patchJVB.containerSecurityContext.readOnlyRootFilesystem | bool | `true` | Mounts the container's root filesystem as read-only. |
| patchJVB.enabled | bool | `true` | Enable post deployment advertisement for LoadBalancer IP or NodePort port to JVB. |
| patchJVB.image.imagePullPolicy | string | `"IfNotPresent"` | Define an ImagePullPolicy.  Ref.: https://kubernetes.io/docs/concepts/containers/images/#image-pull-policy  "IfNotPresent" => The image is pulled only if it is not already present locally. "Always" => Every time the kubelet launches a container, the kubelet queries the container image registry to             resolve the name to an image digest. If the kubelet has a container image with that exact digest cached             locally, the kubelet uses its cached image; otherwise, the kubelet pulls the image with the resolved             digest, and uses that image to launch the container. "Never" => The kubelet does not try fetching the image. If the image is somehow already present locally, the            kubelet attempts to start the container; otherwise, startup fails  |
| patchJVB.image.registry | string | `""` | Container registry address. This setting has higher precedence than global.registry. |
| patchJVB.image.repository | string | `"bitnami/kubectl"` | Container repository string. |
| patchJVB.image.tag | string | `"1.26.6"` | Define image tag. |
| patchJVB.imagePullSecrets | list | `[]` | Credentials to fetch images from private registry Ref: https://kubernetes.io/docs/tasks/configure-pod-container/pull-image-private-registry/  imagePullSecrets:   - "docker-registry"  |
| patchJVB.podSecurityContext.enabled | bool | `false` | Enable security context. |
| patchJVB.resources.limits.cpu | string | `"100m"` | The max amount of CPUs to consume. |
| patchJVB.resources.limits.memory | string | `"128Mi"` | The max amount of RAM to consume. |
| patchJVB.resources.requests.cpu | string | `"10m"` | The amount of CPUs which has to be available on the scheduled node. |
| patchJVB.resources.requests.memory | string | `"16Mi"` | The amount of RAM which has to be available on the scheduled node. |
| podAnnotations | object | `{}` | Pod Annotations. Ref: https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations/ |
| podLabels | object | `{}` | Pod Labels. Ref: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ |
| podSecurityContext.enabled | bool | `false` | Enable security context. |
| rbac.create | bool | `true` | Enable RBAC Role and RoleBinding creation. |
| replicaCount | int | `1` | Set the amount of replicas of deployment. |
| resources.limits.cpu | string | `"100m"` | The max amount of CPUs to consume. |
| resources.limits.memory | string | `"128Mi"` | The max amount of RAM to consume. |
| resources.requests.cpu | string | `"10m"` | The amount of CPUs which has to be available on the scheduled node. |
| resources.requests.memory | string | `"16Mi"` | The amount of RAM which has to be available on the scheduled node. |
| service.annotations | object | `{}` | Additional custom annotations |
| service.enabled | bool | `true` | Enable kubernetes service creation. |
| service.ports.adapter.containerPort | int | `9000` | Internal port for keycloak adapter. |
| service.ports.adapter.port | int | `9000` | Accessible port for keycloak adapter. |
| service.ports.adapter.protocol | string | `"TCP"` | Keycloak adapter service protocol. |
| service.type | string | `"ClusterIP"` | Choose the kind of Service, one of "ClusterIP", "NodePort" or "LoadBalancer". |
| serviceAccount.annotations | object | `{}` | Additional custom annotations for the ServiceAccount. |
| serviceAccount.automountServiceAccountToken | bool | `true` | Allows auto mount of ServiceAccountToken on the serviceAccount created. Can be set to false if pods using this serviceAccount do not need to use K8s API. |
| serviceAccount.create | bool | `true` | Enable creation of ServiceAccount for pod. |
| serviceAccount.labels | object | `{}` | Additional custom labels for the ServiceAccount. |
| settings.allowUnsecureCert | string | `"false"` | Set true if Keycloak has not a trusted certificate. For the production environment, Keycloak should have a trusted certificate and this value should be false. |
| settings.internalHostname | string | `"0.0.0.0"` |  |
| settings.jwtAlg | string | `"HS256"` |  |
| settings.jwtAppId | string | `"myappid"` |  |
| settings.jwtAppSecret | string | `""` |  |
| settings.jwtExpSecond | string | `"3600"` |  |
| settings.jwtHash | string | `"SHA-256"` |  |
| settings.keycloakClientId | string | `"jitsi"` | Configured client id in keycloak. |
| settings.keycloakRealm | string | `"souvap"` | Keycloak realm name. |
| terminationGracePeriodSeconds | string | `""` | In seconds, time the given to the pod needs to terminate gracefully. Ref: https://kubernetes.io/docs/concepts/workloads/pods/pod/#termination-of-pods |
| tolerations | list | `[]` | Tolerations for pod assignment Ref: https://kubernetes.io/docs/concepts/configuration/taint-and-toleration/ |
| topologySpreadConstraints | list | `[]` | Topology spread constraints rely on node labels to identify the topology domain(s) that each Node is in Ref: https://kubernetes.io/docs/concepts/workloads/pods/pod-topology-spread-constraints/  topologySpreadConstraints:   - maxSkew: 1     topologyKey: failure-domain.beta.kubernetes.io/zone     whenUnsatisfiable: DoNotSchedule |
| updateStrategy.type | string | `"RollingUpdate"` | Set to Recreate if you use persistent volume that cannot be mounted by more than one pods to make sure the pods is destroyed first. |

## Uninstalling the Chart

To install the release with name `my-release`:

```bash
helm uninstall my-release
```

## Signing

### Chart

Helm charts are signed with helm native signing method. You can verify the charts against this GPG key:

```
-----BEGIN PGP PUBLIC KEY BLOCK-----
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=cFEh
-----END PGP PUBLIC KEY BLOCK-----
```

### Images

Container images are signed via [cosign](https://github.com/sigstore/cosign) and can be verified with:

```
-----BEGIN PUBLIC KEY-----
MFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAETIpFd4qC4ThMC4PmFIPulqFVhfD/
1ujC+TfS7hTH7X06tleO6a2Gl2Vkn0k88A4LDmvFfNFoHRnEhVsjcLDNDw==
-----END PUBLIC KEY-----

```

```
cosign verify --key cosign.pub --insecure-ignore-tlog <image>
```

## License
This project uses the following license: Apache-2.0

## Copyright
Copyright (C) 2023 Bundesministerium des Innern und für Heimat, PG ZenDiS "Projektgruppe für Aufbau ZenDiS"
